function pdfy = NormPdfPs(y,mu,s2);
%NormPdfPs    Returns pdf value of normally distributed (univariate) variables
%
%
%
%  Usage:    pdfy = NormPdfPs(y,mu,s2); or
%                 = NormPdfPs(y,mu);
%                 = NormPdfPs(y);
%
%  Input:    y          mxn matrix of values of y which is N(mu,s^2)
%            mu         scalar or 1xn, mean of y, defaults to 0
%            s2         scalar or 1xn, variance of y, defaults to 1
%
%
%  Output:   pdfy       mxn matrix of pdf values
%
%
%
%
%  Paul.Soderlind@unisg.ch, Nov 2002
%------------------------------------------------------------------------------

if nargin < 2;
  mu = 0;
end;
if nargin < 3;
  s2 = 1;
end;


s = sqrt(s2);                                  %Std(log(y))

[m,n] = size(y);

if length(mu)==1;                              %make comparible with y
  mu = repmat(mu,m,n);
elseif length(mu)==n;
  mu = repmat(mu(:)',m,1);
end;

if length(s)==1;                              %make comparible with y
  s = repmat(s,m,n);
elseif length(s)==n;
  s = repmat(s(:)',m,1);
end;

pdfy  = exp(-0.5*((y-mu)./s).^2)./(sqrt(2*pi)*s);   %pdf of y ~ N(mu,s^2)
%------------------------------------------------------------------------------

