function [loss,TheoryProb_Interval] = NormalHistLossMultiNom1(par,Probs,Bounds,MultinomialIt,SkewIt);
%NormalHistLossMultiNom  loss function from observed histogram and fitted probabilities
%
%
%
%
%
%   n interval boundaries, z(1), z(2), and z(3) for which
%   the survey gives the following probabilities:
%
%   Pr(x < z(1)), Pr(z(1) <= x <z(2)), Pr(z(2) <= x< z(3)), and Pr(z(3) <= x),
%
%   so there are n+1 categories (and therefore probabilities)
%
%   Notice: both the lowest and the highest intervals are open
%
%
%   Paul Soderlind (Paul.Soderlind@unisg.ch), Oct 2007
%------------------------------------------------------------------------------

if nargin < 4;
  MultinomialIt = [];
  SkewIt        = [];
elseif nargin < 5;
  SkewIt        = [];
end;


n = size(Bounds,1);                        %n bounds, n+1 categories

mu = par(1);
s2 = par(2)^2;
if SkewIt == 1;                             %skew-normal distribution
  error('this version does not support the skew-normal distribution');
  lambda = par(3);
  TheoryProb_x = sndist2(Bounds,mu,sqrt(s2),lambda);       %theoretical Pr( z<=x(i) )
else;                                       %normal distribution
  xnorm        = (Bounds-mu)./sqrt(s2);                    %(x-mu)/s
  TheoryProb_x = 0.5 + 0.5*erf(xnorm/sqrt(2));             %theoretical Pr( z<=x(i) )
end;

TheoryProb_Interval = [ TheoryProb_x(1)                        ;
                        TheoryProb_x(2:n) - TheoryProb_x(1:n-1);
                        1-TheoryProb_x(n)                      ];

% disp( sprintf('%8.2f',par(:)') );
% disp( sprintf('%8.2f',Bounds') );
% disp( sprintf('%8.2f',TheoryProb_Interval') );
% disp(' ');

if MultinomialIt == 1;                     %tau=0.2, ECB recommendation
  tau = 0.2;
  vv = TheoryProb_Interval > eps;
  vv = 1:length(TheoryProb_Interval);
  vv2 = TheoryProb_Interval < eps;
  TheoryProb_Interval(vv2) = eps;
  loss = 1000*1/(tau*(tau+1))*sum( Probs(vv).*((Probs(vv)./TheoryProb_Interval(vv)).^tau - 1) );
elseif MultinomialIt == 2;                 %chi-square
  vv = TheoryProb_Interval > eps;
  loss = 1000*sum( Probs(vv).*log(Probs(vv)./TheoryProb_Interval(vv)) );
elseif MultinomialIt == 3;                 %Kullback-Leibler, see Mittelhammer et al p 316
  vv = TheoryProb_Interval > eps;
  loss = 1000*sum(  TheoryProb_Interval(vv).*log(TheoryProb_Interval(vv)./Probs(vv)) );
else;                                      %LS
  loss = 10000*sum(  (TheoryProb_Interval-Probs).^2  );  %loss function
end;
%----------------------------------------------------------------------------


